#!/usr/bin/perl -w
# ダウンロードした複数種の相同な遺伝子を GenBank format から AA seq と DNA seq を得て，これを cDNA としてアライメントする．
# mafft がインストールされている必要があります．

# GenBankParser_AA_DNA.pl sequence.gb

use strict;
use warnings;

##### infile 名の拡張子を取り除く
my $inFile = "$ARGV[0]";                   # インファイル．cDNA アライメント．
my $inFileNoSu = "";

$inFileNoSu = $inFile;
$inFileNoSu =~ s/\..+$//g;


###### infile, cDNA アライメントファイルを配列に格納する．
my $outAAfile = "010_".$inFileNoSu."_AA.fas";
my $outDNAfile = "010_".$inFileNoSu."_DNA.fas";
my $mafftOut = "010_".$inFileNoSu.".maf";
my $p2nOut = "020_".$inFileNoSu.".p2n";


my $accNum = "";
my $SpName = "";
my $aaSeq = "";
my $dnaSeq = "";
my @inFileCont = ( );

my $aaStone = 0;
my $dnaStone = 0;

###

open(INFILE,"$inFile");
open(AASEQ,">$outAAfile"); 
open(DNASEQ,">$outDNAfile");
while(my $line = <INFILE>){
  chomp($line);
 if($line =~ /^ACCESSION   /){
   $accNum = $line;
   $accNum =~ s/ACCESSION   //g;
 }
 if($line =~ /^  ORGANISM/){
   $line =~ s/  ORGANISM  //g;
   $line =~ s/[^a-zA-Z]/_/g;
   $SpName = $line;
 }


 # DNAseq を集める．
 if($line =~ /^\/\//){
   print DNASEQ ">$SpName\_$accNum\n$dnaSeq\n";
   $dnaSeq = "";
   $dnaStone = 0;
 }
 if($dnaStone == 1){
   $line =~ s/[^a-zA-Z]//g;
   $dnaSeq .= $line;
 }

 # AAseq を集める．
 if($line =~ /^ORIGIN/){
   print AASEQ ">$SpName\_$accNum\n$aaSeq\n";
   $aaSeq = "";
   $aaStone = 0;
   $dnaStone = 1;
 }
 if($aaStone == 1){
   $line =~ s/[^a-zA-Z]//g;
   $aaSeq .= $line;
 }
 if($line =~ /\/translation=/){
   $line =~ s/\/translation=//g;
   $line =~ s/[^a-zA-Z]//g;
   $aaSeq = $line;
   $aaStone = 1;

 }

}
close AASEQ;
close DNASEQ;
close INFILE;

system("mafft $outAAfile > $mafftOut");
system("pal2nal.pl $mafftOut $outDNAfile -output fasta > $p2nOut");
system("FasToNex_cDNA.pl $p2nOut");

exit;